summaryrefslogtreecommitdiffstats
path: root/libkdepim/kpartsdesignerplugin/kpartsdesignerplugin.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'libkdepim/kpartsdesignerplugin/kpartsdesignerplugin.cpp')
-rw-r--r--libkdepim/kpartsdesignerplugin/kpartsdesignerplugin.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/libkdepim/kpartsdesignerplugin/kpartsdesignerplugin.cpp b/libkdepim/kpartsdesignerplugin/kpartsdesignerplugin.cpp
index 16cb61bb..afe8bad6 100644
--- a/libkdepim/kpartsdesignerplugin/kpartsdesignerplugin.cpp
+++ b/libkdepim/kpartsdesignerplugin/kpartsdesignerplugin.cpp
@@ -47,7 +47,7 @@ void KPartsGenericPart::load()
if ( m_part ) {
delete m_part;
}
// "this" is both the tqparent widget and the tqparent object
m_part = KParts::ComponentFactory::createPartInstanceFromQuery<KParts::ReadOnlyPart>( mimetype, TQString(), TQT_TQWIDGET(this), 0, TQT_TQOBJECT(this), 0 );
if ( m_part ) {
m_part->openURL( m_url );
@@ -63,9 +63,9 @@ TQStringList KPartsWidgetPlugin::keys() const {
return TQStringList() << mykey;
}
-TQWidget * KPartsWidgetPlugin::create( const TQString & key, TQWidget * tqparent, const char * name ) {
+TQWidget * KPartsWidgetPlugin::create( const TQString & key, TQWidget * parent, const char * name ) {
if ( key == mykey )
- return new KPartsGenericPart( tqparent, name );
+ return new KPartsGenericPart( parent, name );
return 0;
}
@@ -47,7 +47,7 @@ void KPartsGenericPart::load()
delete m_part;
}
- // "this" is both the tqparent widget and the tqparent object
+ // "this" is both the parent widget and the parent object
m_part = KParts::ComponentFactory::createPartInstanceFromQuery<KParts::ReadOnlyPart>( mimetype, TQString(), TQT_TQWIDGET(this), 0, TQT_TQOBJECT(this), 0 );
if ( m_part ) {